pysmsboxnet
===========

.. automodule:: pysmsboxnet.api

.. autoclass:: pysmsboxnet.api.Client
   :members: send, get_credits

Exceptions
==========

The following exceptions can be thrown.

All exceptions are not applicable to all case but some are common, for example in case of an internal error or bad API key provided.

.. automodule:: pysmsboxnet.exceptions
   :members:
